//
//  SkypeBridge.h
//  SkypePlugin
//
//  Created by Brandon M. Holland on 16/01/08.
//  Copyright 2008 What a Nutbar Software. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <Skype/Skype.h>
#import "SkypeConstants.h"

@interface SkypeBridge : NSObject <SkypeAPIDelegate>
{
	id bridgeDelegate, userDelegate, callDelegate, contactsDelegate;
	NSString *skypeVersion;
	NSMutableDictionary *contacts;
	NSArray *hardGroups;
	SkypeConnectStatus connectStatus;
	SkypeStatus currentStatus;
	SkypeCallStatus currentCallStatus;
	NSString *currentHandle;
	NSString *currentFullName;
	NSString *currentMood;
	NSString *currentBalance;
	NSString *currentCurrency;
	NSString *currentCall;
	NSString *currentInput; 
	NSString *currentOutput; 
	NSString *currentAuthorization;
	BOOL bridgeReady;
}

+ (SkypeBridge *)bridge;
+ (void)startBridge;
+ (void)stopBridge;
+ (void)setBridgeDelegate: (id) delegate;
+ (void)setUserDelegate: (id) delegate;
+ (void)setCallDelegate: (id) delegate;
+ (void)setContactsDelegate: (id) delegate;
+ (void)removeBridgeDelegate;
+ (void)removeUserDelegate;
+ (void)removeCallDelegate;
+ (void)removeContactsDelegate;

- (BOOL) isSkypeRunning;
- (BOOL) isBridgeReady;
- (void) parseSkypeCommand: (NSString *) skypeString;
- (NSMutableDictionary *) getUserForHandle: (NSString *) handle fromBuddy: (BOOL) fromBuddy;
- (NSString *)sysSkypeVersion;
- (NSString *)currentUserHandle;
- (NSString *)currentUserFullName;
- (NSString *)currentUserMood;
- (NSString *)currentUserBalance;
- (NSString *)currentUserCurrency;
- (SkypeStatus)currentUserStatus;
- (void) setCurrentUserStatus: (SkypeStatus) newStatus;
- (void) setCurrentUserFullName: (NSString *) newFullName;
- (void) setCurrentUserMood: (NSString *) newMood;

- (SkypeConnectStatus)sysConnectStatus;
- (NSString *)currentAudioOutput;
- (NSString *)currentAudioInput;
- (void)setAudioOutput: (NSString *) newOutput;
- (void)setAudioInput: (NSString *) newInput;

- (NSArray *)handleList;
- (NSString *)fullNameForHandle: (NSString *) handle;
- (NSString *)moodForHandle: (NSString *) handle;
- (SkypeStatus)onlineStatusForHandle: (NSString *) handle;
- (BOOL) isAuthorizedForHandle: (NSString *) handle;
- (BOOL) isBlockedForHandle: (NSString *) handle;
- (void) refreshContacts;
- (void) unauthorizeUserForHandle: (NSString *) handle;
- (void) authorizeUserForHandle: (NSString *) handle;
- (void) unBlockUserWithHandle: (NSString *) handle;
- (void) blockUserWithHandle: (NSString *) handle;
- (void) addUserWithHandle: (NSString *) handle addMessage: (NSString *) message;
- (void) removeUserWithHandle: (NSString *) handle;
- (void) callUserForHandle: (NSString *) handle;
- (void) endCurrentCall;
- (void) pauseCurrentCall;
- (void) resumeCurrentCall;
- (void) seenCurrentCall;
@end

@interface NSObject (SkypeBridge)
- (void) bridgeBalanceUpdated: (NSString *) newBalance;
- (void) bridgeMoodUpdated: (NSString *) newMood;
- (void) bridgeFullNameUpdated: (NSString *) newFullName;
- (void) bridgeStatusUpdated: (SkypeStatus) newStatus;
- (void) bridgeConnectionUpdated: (SkypeConnectStatus) newConStatus;
- (void) bridgeIsReady: (BOOL) ready;
- (void) userUpdatedForHandle: (NSString *) handle;
- (void) contactRemovedForHandle: (NSString *) handle;
- (void) callStatusUpdatedForCall: (SkypeCallStatus) status;
- (void) callDurationUpdatedForCall: (NSString *) duration;
- (void) incomingAuthorizationFromHandle: (NSString *) handle withMessage: (NSString *) authMsg;
- (void) incomingCallFromHandle: (NSString *) handle;
- (void) contactsUpdated;
@end
